@@ -910,15 +910,15 @@ shiny.bigKRLS <- function(out, export=F, main.label = "bigKRLS estimates", plot.
     
     selectedData <- reactive({
       
-      return(cbind(as.numeric(out$derivatives[, input$dydxp]), 
-                    as.numeric(out$X[, input$xp])))
+      return(list(x = as.numeric(out$X[, input$xp]),
+             derivatives = as.numeric(out$derivatives[, input$dydxp])))
     })
     
     output$graph <- renderPlot({
       
       P = ggplot(NULL) 
-      P = P + geom_point(aes(x = selectedData()[,1], y = selectedData()[,2]), alpha = 1, size=.1, color='grey') 
-      P = P +  geom_smooth(aes(x=selectedData()[,1], y = selectedData()[,2]), method='loess') + xlab(input$xp) 
+      P = P + geom_point(aes(x = selectedData()[["x"]], y = selectedData()[["derivatives"]]), alpha = 1, size=.1, color='grey') 
+      P = P +  geom_smooth(aes(x = selectedData()[["x"]], y = selectedData()[["derivatives"]]), method='loess') + xlab(input$xp) 
       P = P +  ylab(paste('Marginal Effects of ', input$dydxp)) 
       P = P +  geom_hline(aes(yintercept=hline))
       P = P +  theme_minimal(base_size = font_size)
@@ -958,7 +958,7 @@ shiny.bigKRLS <- function(out, export=F, main.label = "bigKRLS estimates", plot.
     
     cat("A re-formatted version of your output has been saved with file name \"shiny_out.rdata\" in your current working directory:\n", getwd(),
         "\nFor a few technical reasons, the big N * N matrices have been removed and the smaller ones converted back to base R;\nthis should make your output small enough for the free version of Shiny's server.\nTo access the Shiny app later or on a different machine, simply execute this script with the following commands:\n",
-        "\nload(\"shiny_out.rdata\")\nNext, execute this script to make sure Shiny is initialized with current values. \nshiny_bigKRLS(out)")
+        "\nload(\"shiny_out.rdata\")\nNext, execute this code:\n\nshiny.bigKRLS(output_baseR)")
   }else{
     shinyApp(ui = bigKRLS_ui, server = bigKRLS_server)
   }
